@@ -20,7 +20,7 @@ General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program. If not, see <https://www.gnu.org/licenses/>.
-"""
+"""  # noqa
 from __future__ import annotations
 
 import logging
@@ -82,8 +82,6 @@ class GuiMainMenu(QMenuBar):
 
         logger.debug("Ready: GuiMainMenu")
 
-        return
-
     ##
     #  Public Slots
     ##
@@ -92,7 +90,18 @@ class GuiMainMenu(QMenuBar):
     def setSpellCheckState(self, state: bool) -> None:
         """Forward spell check check state to its action."""
         self.aSpellCheck.setChecked(state)
-        return
+
+    @pyqtSlot()
+    def updateSpellCheckLanguages(self) -> None:
+        """Update the list of available spell check languages."""
+        self.mSelectLanguage.clear()
+        languages = SHARED.spelling.listDictionaries()
+        languages.insert(0, ("None", self.tr("Default")))
+        for tag, language in languages:
+            aSpell = QAction(self.mSelectLanguage)
+            aSpell.setText(language)
+            aSpell.triggered.connect(qtLambda(self._changeSpelling, tag))
+            self.mSelectLanguage.addAction(aSpell)
 
     ##
     #  Private Slots
@@ -105,21 +114,18 @@ class GuiMainMenu(QMenuBar):
         decision, just pass a None to the function and let it decide.
         """
         self.mainGui.docEditor.toggleSpellCheck(None)
-        return
 
     @pyqtSlot()
     def _openUserManualFile(self) -> None:
         """Open the documentation in PDF format."""
         if isinstance(CONFIG.pdfDocs, Path):
             openExternalPath(CONFIG.pdfDocs)
-        return
 
     @pyqtSlot(str)
     def _changeSpelling(self, language: str) -> None:
         """Change the spell check language."""
         SHARED.project.data.setSpellLang(language)
         SHARED.updateSpellCheckLanguage()
-        return
 
     ##
     #  Internal Functions
@@ -188,8 +194,6 @@ class GuiMainMenu(QMenuBar):
         self.aExitNW.triggered.connect(qtLambda(self.mainGui.closeMain))
         self.mainGui.addAction(self.aExitNW)
 
-        return
-
     def _buildDocumentMenu(self) -> None:
         """Assemble the Document menu."""
         # Document
@@ -236,8 +240,6 @@ class GuiMainMenu(QMenuBar):
         self.aImportFile = qtAddAction(self.docuMenu, self.tr("Import Text from File"))
         self.aImportFile.triggered.connect(qtLambda(self.mainGui.importDocument))
 
-        return
-
     def _buildEditMenu(self) -> None:
         """Assemble the Edit menu."""
         # Edit
@@ -305,8 +307,6 @@ class GuiMainMenu(QMenuBar):
         )
         self.mainGui.addAction(self.aSelectPar)
 
-        return
-
     def _buildViewMenu(self) -> None:
         """Assemble the View menu."""
         # View
@@ -318,6 +318,7 @@ class GuiMainMenu(QMenuBar):
         self.aFocusTree.triggered.connect(
             lambda: self.requestFocusChange.emit(nwFocus.TREE)
         )
+        self.mainGui.addAction(self.aFocusTree)
 
         # View > Document Editor
         self.aFocusDocument = qtAddAction(self.viewMenu, self.tr("Go to Document"))
@@ -332,6 +333,7 @@ class GuiMainMenu(QMenuBar):
         self.aFocusOutline.triggered.connect(
             lambda: self.requestFocusChange.emit(nwFocus.OUTLINE)
         )
+        self.mainGui.addAction(self.aFocusOutline)
 
         # View > Separator
         self.viewMenu.addSeparator()
@@ -365,8 +367,6 @@ class GuiMainMenu(QMenuBar):
         self.aFullScreen.triggered.connect(self.mainGui.toggleFullScreenMode)
         self.mainGui.addAction(self.aFullScreen)
 
-        return
-
     def _buildInsertMenu(self) -> None:
         """Assemble the Insert menu."""
         # Insert
@@ -644,8 +644,6 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocInsert.emit(nwDocInsert.FOOTNOTE)
         )
 
-        return
-
     def _buildFormatMenu(self) -> None:
         """Assemble the Format menu."""
         # Format
@@ -675,6 +673,14 @@ class GuiMainMenu(QMenuBar):
         )
         self.mainGui.addAction(self.aFmtStrike)
 
+        # Format > Highlight
+        self.aFmtMark = qtAddAction(self.fmtMenu, self.tr("Highlight"))
+        self.aFmtMark.setShortcut("Ctrl+M")
+        self.aFmtMark.triggered.connect(
+            lambda: self.requestDocAction.emit(nwDocAction.MD_MARK)
+        )
+        self.mainGui.addAction(self.aFmtStrike)
+
         # Edit > Separator
         self.fmtMenu.addSeparator()
 
@@ -891,8 +897,6 @@ class GuiMainMenu(QMenuBar):
             lambda: self.requestDocAction.emit(nwDocAction.RM_BREAKS)
         )
 
-        return
-
     def _buildSearchMenu(self) -> None:
         """Assemble the Search menu."""
         # Search
@@ -938,8 +942,6 @@ class GuiMainMenu(QMenuBar):
         self.aFindProj.setShortcut("Ctrl+Shift+F")
         self.aFindProj.triggered.connect(qtLambda(self.requestViewChange.emit, nwView.SEARCH))
 
-        return
-
     def _buildToolsMenu(self) -> None:
         """Assemble the Tools menu."""
         # Tools
@@ -954,13 +956,7 @@ class GuiMainMenu(QMenuBar):
         self.mainGui.addAction(self.aSpellCheck)
 
         self.mSelectLanguage = qtAddMenu(self.toolsMenu, self.tr("Spell Check Language"))
-        languages = SHARED.spelling.listDictionaries()
-        languages.insert(0, ("None", self.tr("Default")))
-        for tag, language in languages:
-            aSpell = QAction(self.mSelectLanguage)
-            aSpell.setText(language)
-            aSpell.triggered.connect(qtLambda(self._changeSpelling, tag))
-            self.mSelectLanguage.addAction(aSpell)
+        self.updateSpellCheckLanguages()
 
         # Tools > Re-Run Spell Check
         self.aReRunSpell = qtAddAction(self.toolsMenu, self.tr("Re-Run Spell Check"))
@@ -1009,8 +1005,6 @@ class GuiMainMenu(QMenuBar):
         self.aPreferences.triggered.connect(self.mainGui.showPreferencesDialog)
         self.mainGui.addAction(self.aPreferences)
 
-        return
-
     def _buildHelpMenu(self) -> None:
         """Assemble the Help menu."""
         # Help
@@ -1056,5 +1050,3 @@ class GuiMainMenu(QMenuBar):
         # Document > Main Website
         self.aWebsite = qtAddAction(self.helpMenu, self.tr("The novelWriter Website"))
         self.aWebsite.triggered.connect(qtLambda(SHARED.openWebsite, nwConst.URL_WEB))
-
-        return
